@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -17,6 +17,7 @@
    Boston, MA 02110-1301, USA.
 */
 #include "grantleeplaintexteditor.h"
+#include "grantleethemeeditor_debug.h"
 
 #include <KSyntaxHighlighting/SyntaxHighlighter>
 #include <KSyntaxHighlighting/Definition>
@@ -32,8 +33,10 @@ using namespace GrantleeThemeEditor;
 GrantleePlainTextEditor::GrantleePlainTextEditor(QWidget *parent)
     : KPIMTextEdit::PlainTextEditor(parent)
 {
-    KSyntaxHighlighting::Definition def;
-    def = mRepo.definitionForName(QStringLiteral("HTML"));
+    const KSyntaxHighlighting::Definition def = mRepo.definitionForName(QStringLiteral("HTML"));
+    if (!def.isValid()) {
+        qCWarning(GRANTLEETHEMEEDITOR_LOG) << "Invalid definition name";
+    }
 
     KSyntaxHighlighting::SyntaxHighlighter *hl = new KSyntaxHighlighting::SyntaxHighlighter(document());
     hl->setTheme((palette().color(QPalette::Base).lightness() < 128)
